
# Type: location of


holds between material entity or site and a material entity that is located within it (but not considered a part of it)

URI: [biolink:location_of](https://w3id.org/biolink/vocab/location_of)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>0..*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children


## Used by

 * [NamedThing](NamedThing.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | RO:0001015 |
|  | | SEMMEDDB:LOCATION_OF |
|  | | WD:276 |
| **In Subsets:** | | translator_minimal |

